@@ -1,7 +1,7 @@
 /***************************************************************************
                       codegenerator.cpp  -  description
                              -------------------
-    copyright            : (C) 2007-2023 by Andre Simon
+    copyright            : (C) 2007-2024 by Andre Simon
     email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -34,6 +34,8 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 #include <cstdlib>
 #include <cstring>
 #include <fstream>
+#include <array>
+
 #include "version.h"
 
 #include "pangogenerator.h"
@@ -50,7 +52,7 @@ namespace ansifilter
 
 CodeGenerator * CodeGenerator::getInstance(OutputType type)
 {
-    CodeGenerator* generator=NULL;
+    CodeGenerator* generator=nullptr;
     switch (type) {
     case TEXT:
         generator = new PlaintextGenerator();
@@ -84,8 +86,8 @@ CodeGenerator * CodeGenerator::getInstance(OutputType type)
 }
 
 CodeGenerator::CodeGenerator(ansifilter::OutputType type)
-    :in(NULL),
-     out(NULL),
+    :in(nullptr),
+     out(nullptr),
      tagIsOpen(false),
      encoding("none"),
      docTitle("Source file"),
@@ -112,7 +114,7 @@ CodeGenerator::CodeGenerator(ansifilter::OutputType type)
      omitTrailingCR(false),
      ignClearSeq(false),
      ignCSISeq(false),
-     termBuffer(NULL),
+     termBuffer(nullptr),
      curX(0),
      curY(0),
      memX(0),
@@ -122,12 +124,14 @@ CodeGenerator::CodeGenerator(ansifilter::OutputType type)
      asciiArtHeight(150),
      lineWrapLen(0)
 {
-    elementStyle.setFgColour(rgb2html(workingPalette[0]));
 }
 
-CodeGenerator::~CodeGenerator()
-{}
+CodeGenerator::~CodeGenerator() = default;
 
+void CodeGenerator::setDefaultForegroundColor()
+{
+    elementStyle.setFgColour(rgb2html(workingPalette[0]));
+}
 
 void CodeGenerator::setShowLineNumbers(bool flag)
 {
@@ -210,10 +214,8 @@ void CodeGenerator::setStyleSheet(const std::string& path)
 }
 
 void CodeGenerator::setPreformatting ( WrapMode lineWrappingStyle,
-                                       unsigned int lineLength
-                                     )
+                                       unsigned int lineLength)
 {
-
     lineWrapLen = lineLength;
 }
 
@@ -261,11 +263,11 @@ ParseError CodeGenerator::generateFile (const string &inFileName,
 
     if (!outFileName.empty()) {
         delete out;
-        out=NULL;
+        out=nullptr;
     }
     if (!inFileName.empty()) {
         delete in;
-        in=NULL;
+        in=nullptr;
     }
     return error;
 }
@@ -292,9 +294,9 @@ string CodeGenerator::generateString(const string &input)
     string result = static_cast<ostringstream*>(out)->str();
 
     delete out;
-    out=NULL;
+    out=nullptr;
     delete in;
-    in=NULL;
+    in=nullptr;
 
     return result;
 }
@@ -322,9 +324,9 @@ string CodeGenerator::generateStringFromFile(const string &inFileName)
     string result = static_cast<ostringstream*>(out)->str();
 
     delete out;
-    out=NULL;
+    out=nullptr;
     delete in;
-    in=NULL;
+    in=nullptr;
 
     return result;
 }
@@ -362,11 +364,11 @@ ParseError CodeGenerator::generateFileFromString (const string &sourceStr,
 
     if (!outFileName.empty()) {
         delete out;
-        out=NULL;
+        out=nullptr;
     }
 
     delete in;
-    in=NULL;
+    in=nullptr;
 
     return error;
 }
@@ -378,7 +380,6 @@ bool CodeGenerator::printDynamicStyleFile ( const string &outPath )
 }
 
 /*
-
  ESC[nL       Inserts n blank lines at cursor line.   (NANSI)
  ESC[nM       Deletes n lines including cursor line.  (NANSI)
  ESC[n@       Inserts n blank chars at cursor.        (NANSI)
@@ -400,7 +401,7 @@ bool CodeGenerator::parseSGRParameters(const string& line, size_t begin, size_t
     string codes=line.substr(begin, end-begin);
     vector<string> codeVector = StringTools::splitString(codes, ';');
 
-    vector<string>::iterator itVectorData = codeVector.begin();
+    auto itVectorData = codeVector.begin();
     while( itVectorData != codeVector.end()) {
         StringTools::str2num<int>(ansiCode, *(itVectorData), std::dec);
         elementStyle.setReset(false);
@@ -646,7 +647,7 @@ void CodeGenerator::parseCodePage437Seq(string line, size_t begin, size_t end){
       curX++;
     }
 
-    //handle coloumn overflow
+    //handle column overflow
     if (curX>asciiArtWidth && curY<asciiArtHeight){
       curX-=asciiArtWidth;
       curY++;
@@ -710,9 +711,9 @@ void CodeGenerator::insertLineNumber ()
 
 void CodeGenerator::printTermBuffer() {
 
-    for (int y=0;y<=maxY;y++) {
+    for (unsigned int y=0;y<=maxY;y++) {
 
-        for (int x=0;x<asciiArtWidth;x++) {
+        for (unsigned int x=0;x<asciiArtWidth;x++) {
             if (termBuffer[x + y* asciiArtWidth].c=='\r') {
                 break;
             }
@@ -990,7 +991,7 @@ void CodeGenerator::allocateTermBuffer(){
   if (termBuffer) delete [] termBuffer;
 
   termBuffer = new TDChar[asciiArtWidth*asciiArtHeight];
-  for (int i=0; i<asciiArtWidth*asciiArtHeight; i++){
+  for (unsigned int i=0; i<asciiArtWidth*asciiArtHeight; i++){
     termBuffer[i].c=0;
   }
 }
@@ -1080,6 +1081,7 @@ void CodeGenerator::processInput()
   size_t i=0;
   size_t plainTxtCnt=0;
   bool tagOpen=false;
+
   bool isGrepOutput=false;
   bool isKSeq=false;
 
@@ -1102,7 +1104,7 @@ void CodeGenerator::processInput()
     numberCurrentLine = true;
 
     if (eof) {
-      // imitate tail bahaviour, continue to read after EOF
+      // imitate tail behaviour, continue to read after EOF
       if (readAfterEOF) {
         out->flush();
         in->clear();
@@ -1181,10 +1183,12 @@ void CodeGenerator::processInput()
         } else {
 
           if ( (cur&0xff)==0x0d && i<line.length()-1) {
+
             plainTxtCnt-=i;
 
             lineBuf.seekp(showLineNumbers ? 0 : 0, ios::beg);
-            lineBuf<<getOpenTag();
+            //lineBuf<<getOpenTag();
+
           }
             // wrap line
           if (lineWrapLen && plainTxtCnt && plainTxtCnt % lineWrapLen==0) {
@@ -1271,7 +1275,7 @@ void CodeGenerator::processInput()
 
                   // fix K sequences (iterm2/grep)
                   isKSeq =  line[seqEnd]=='K' && !ignClearSeq ;
-                  isGrepOutput = isKSeq && isascii(line[seqEnd+1]) && line[seqEnd+1] !=13 && line[seqEnd+1] != 27;
+                  isGrepOutput = isKSeq && line.length() > (seqEnd + 1) && isascii(line[seqEnd+1]) && line[seqEnd+1] !=13 && line[seqEnd+1] != 27;
 
                   if (   line[seqEnd]=='s' || line[seqEnd]=='u'
                     || (isKSeq && !isGrepOutput) ){
@@ -1299,7 +1303,7 @@ void CodeGenerator::processInput()
                         ++seqEnd;
                     }
 
-                    if (line[seqEnd+1]=='A')
+                    if (line.length() > (seqEnd + 1) && line[seqEnd+1]=='A')
                         seqEnd++;
 
                     i=seqEnd+1;
@@ -1308,7 +1312,7 @@ void CodeGenerator::processInput()
 
                 ) ) // DECSC seq
                 {
-                    if (line[seqEnd+1]==0x1b)
+                    if (line.length() > (seqEnd + 1) && line[seqEnd+1]==0x1b)
                         ++i;
                 }
               }
@@ -1394,15 +1398,16 @@ void CodeGenerator::xterm2rgb(unsigned char color, unsigned char* rgb)
 }
 
 string CodeGenerator::rgb2html(unsigned char* rgb){
-  char colorString[10]= {0};
-  sprintf(colorString, "#%02x%02x%02x", rgb[0], rgb[1], rgb[2]);
-  return string(colorString);
+
+  std::array<char, 8> colorString;  // 7 characters for "#RRGGBB" and 1 for '\0'
+  std::snprintf(colorString.data(), colorString.size(), "#%02x%02x%02x", rgb[0], rgb[1], rgb[2]);
+  return std::string(colorString.data());
 }
 
 string CodeGenerator::rgb2html(int r, int g, int b){
-  char colorString[10]= {0};
-  sprintf(colorString, "#%02x%02x%02x", r, g, b);
-  return string(colorString);
+  std::array<char, 8> colorString;  // 7 characters for "#RRGGBB" and 1 for '\0'
+  std::snprintf(colorString.data(), colorString.size(), "#%02x%02x%02x", r, g, b);
+  return std::string(colorString.data());
 }
 
 const unsigned char CodeGenerator::valuerange[] = { 0x00, 0x5F, 0x87, 0xAF, 0xD7, 0xFF };
@@ -1473,9 +1478,9 @@ bool CodeGenerator::setColorMap(const string& mapPath){
 
         s>>colorCode;
         if (colorCode.size()>=7 && colorCode[0]=='#' ) {
-          workingPalette[idx][0] = (char)std::strtol(colorCode.substr ( 1, 2 ).c_str(), NULL, 16);
-          workingPalette[idx][1] = (char)std::strtol(colorCode.substr ( 3, 2 ).c_str(), NULL, 16);
-          workingPalette[idx][2] = (char)std::strtol(colorCode.substr ( 5, 2 ).c_str(), NULL, 16);
+          workingPalette[idx][0] = (char)std::strtol(colorCode.substr ( 1, 2 ).c_str(), nullptr, 16);
+          workingPalette[idx][1] = (char)std::strtol(colorCode.substr ( 3, 2 ).c_str(), nullptr, 16);
+          workingPalette[idx][2] = (char)std::strtol(colorCode.substr ( 5, 2 ).c_str(), nullptr, 16);
         } else {
           return false;
         }
