@@ -1,7 +1,7 @@
 /***************************************************************************
                           codegenerator.h  -  description
                              -------------------
-    copyright            : (C) 2007-2023 by Andre Simon
+    copyright            : (C) 2007-2024 by Andre Simon
     email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -28,6 +28,7 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 #include <iostream>
 #include <sstream>
 #include <string>
+#include <string_view>
 #include <vector>
 #include <iomanip>
 
@@ -40,6 +41,25 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 #include "enums.h"
 #include "stringtools.h"
 
+
+using std::string;
+using std::vector;
+using std::cin;
+using std::cout;
+using std::cerr;
+using std::istream;
+using std::ostream;
+using std::stringstream;
+using std::istringstream;
+using std::ostringstream;
+using std::ofstream;
+using std::ifstream;
+using std::ios;
+using std::right;
+using std::setw;
+using std::ios;
+
+
 /// The ansifilter namespace contains all classes and data structures needed for parsing input data.
 
 namespace ansifilter
@@ -57,7 +77,7 @@ namespace ansifilter
 public:
 
     /// Constructor
-    StyleInfo() :  fgColor ( "" ), bgColor ( "" ),  isBold (false),isItalic (false),isConcealed (false), isBlink (false), isUnderLine (false)
+    StyleInfo() :  fgColor ( "" ), bgColor ( "" ), isBold (false), isItalic (false), isConcealed (false), isBlink (false), isUnderLine (false)
     {
     }
 
@@ -135,7 +155,7 @@ public:
 
     /**
       Delete Codegenerator instance (this is intended for SWIG integration,
-      in normal C++ code the result should be saved in an auto_ptr)
+      in normal C++ code the result should be saved in a unique_ptr)
       \param CodeGenerator* CodeGenerator instance
     */
     static void deleteInstance(CodeGenerator* inst)
@@ -189,6 +209,11 @@ public:
     */
     bool setColorMap(const string& mapPath);
 
+    /**
+     Initialize default foreground color
+    */
+    void setDefaultForegroundColor();
+
     /** tell parser to omit document header and footer
        \param  flag true if output should be fragmented
     */
@@ -327,7 +352,11 @@ protected:
     /** \param uri URI
      *  \param txt Description
      \return returns link formatting sequence */
-    virtual string getHyperlink(string uri, string txt) { return txt+"["+uri+"]"; }
+    virtual string getHyperlink(std::string_view uri, std::string_view txt) {
+        ostringstream os;
+        os << txt << "[" << uri << "]";
+        return os.str();
+    }
 
     /** Tag for inserting line feeds*/
     string newLineTag;
@@ -458,15 +487,15 @@ private:
     virtual string getCloseTag() = 0; ///< returns closing formatting sequence
 
     bool ignoreFormatting; ///< ignore color and font face information
-    bool readAfterEOF;     ///< continue reading after EOF occoured
+    bool readAfterEOF;     ///< continue reading after EOF occurred
     bool omitTrailingCR;   ///< do not print EOL at the end of output
     bool ignClearSeq;      ///< ignore clear sequence ESC K
     bool ignCSISeq;       ///< ignore CSIs (may interfere with UTF-8 input)
 
     TDChar* termBuffer;
-    int curX, curY, memX, memY, maxY; ///< cursor position for Codepage 437 sequences
-    int asciiArtWidth;        ///< virtual console column count
-    int asciiArtHeight;       ///< virtual console line count
+    unsigned int curX, curY, memX, memY, maxY; ///< cursor position for Codepage 437 sequences
+    unsigned int asciiArtWidth;        ///< virtual console column count
+    unsigned int asciiArtHeight;       ///< virtual console line count
     unsigned int lineWrapLen; ///< max line length before wrapping
 
     ElementStyle memStyle;
