@@ -28,6 +28,7 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 #define LATEXGENERATOR_H
 
 #include <string>
+#include <string_view>
 
 #include "codegenerator.h"
 
@@ -77,7 +78,7 @@ private:
     /** \return escaped character*/
     virtual string maskCharacter(unsigned char );
 
-    virtual string getHyperlink(string uri, string txt);
+    virtual string getHyperlink(std::string_view uri, std::string_view txt);
 
     void insertLineNumber();
 };
