@@ -1,3 +1,10 @@
+/***************************************************************************
+                          platform_fs.h  -  description
+                             -------------------
+    begin                : Sun Oct 13 2007
+    copyright            : (C) 2007-2020 by Andre Simon
+    email                : a.simon@mailbox.org
+ ***************************************************************************/
 /*
 This file is part of ANSIFilter.
 
@@ -23,8 +30,7 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 namespace Platform
 {
 extern const char pathSeparator;
-//extern const std::string pathSeparatorStr;
 
-std::string getAppPath();
+off_t fileSize(const std::string& fName);
 }
 #endif
