@@ -30,6 +30,8 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 #include "ui_ansifilter.h"
 #include "codegenerator.h"
 
+using std::string;
+using std::unique_ptr;
 
 class MyDialog : public QDialog
 {
@@ -37,7 +39,7 @@ class MyDialog : public QDialog
 public:
                 Ui::Dialog dlg;
                 //The same constructor that we used last time with QDialog default parameters
-                MyDialog(QWidget * parent = 0, Qt::WindowFlags f = 0);
+                MyDialog(QWidget * parent = 0, Qt::WindowFlags f = Qt::Window);
 
 
                 void setInputFileName(const char* fName) {
@@ -46,7 +48,7 @@ public:
                 }
 
                 virtual ~MyDialog() {}
-                
+
 protected:
                 void closeEvent(QCloseEvent *event);
 
@@ -78,7 +80,7 @@ public slots:
                 void on_pbSelectMapFile_clicked();
                 void on_cbParseAsciiArt_clicked();
                 void on_cbIgnClearSeq_clicked();
-
+                void on_cbIgnCSISeq_clicked();
 
                 void on_cbIgnoreSequences_stateChanged();
                 void on_cbWatchFile_stateChanged();
@@ -93,4 +95,3 @@ public slots:
 };
 
 #endif
-
