@@ -2,7 +2,7 @@
                           rtfcode.h  -  description
                              -------------------
 
-    copyright            : (C) 2007 by Andre Simon
+    copyright            : (C) 2007-2024 by Andre Simon
     email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -28,6 +28,7 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <string>
 #include <map>
+#include <string_view>
 #include "codegenerator.h"
 
 
@@ -64,7 +65,7 @@ struct PageSize {
 };
 
 /** mapping of page size names and dimensions */
-typedef  map<string, struct PageSize> PagesizeMap;
+typedef  std::map<string, struct PageSize> PagesizeMap;
 
 class RtfGenerator : public ansifilter::CodeGenerator
 {
@@ -109,18 +110,18 @@ private:
     /** \return escaped character*/
     virtual string maskCP437Character(unsigned char );
 
-    virtual string getHyperlink(string uri, string txt);
+    virtual string getHyperlink(std::string_view uri, std::string_view txt);
 
     /**\return text formatting attributes in RTF format */
     string  getAttributes( const StyleColour & col);
 
     /** @param styleNumber number of current style
         @param elem associated element style
-        @return RTF formatting seqence (colour index + bold + italic)*/
+        @return RTF formatting sequence (colour index + bold + italic)*/
     string getOpenTag();
 
     /** @param elem associated element style
-        @return RTF formatting sequnce to close element formatting */
+        @return RTF formatting sequence to close element formatting */
     string getCloseTag();
 
 
